@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -25,7 +25,7 @@ void showAbout(void)
   strcpy(abouttext,KREATECD_VERSION "\n\n");
   strcat(abouttext,
   locale->translate(
-  "1998-1999 by Alexander Feigl\n\n"
+  "1998-2000 by Alexander Feigl\n\n"
   "Alexander Feigl\n"
   "Burachstrasse 51\n"
   "88250 Weingarten\n\n"
@@ -33,6 +33,6 @@ void showAbout(void)
   "This software is distributed under the\nGNU Public License! Hope youll enjoy it!\n"));
  
   qmsg=new QMessageBox(KREATECD_VERSION,abouttext,QMessageBox::Information,QMessageBox::Ok,0,0);
-  qmsg->setButtonText(QMessageBox::Ok,locale->translate("Great!"));
+  qmsg->setButtonText(QMessageBox::Ok,locale->translate("OK"));
   qmsg->show();
  }
