@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -9,6 +9,7 @@
 #include "AudioOptions.h"
 #include "CDTrack.h"
 #include "AudioFile.h"
+#include "AudioPlayImage.h"
 
 #include <kapp.h>
 #include <klocale.h>
@@ -40,11 +41,16 @@ AudioOptions::AudioOptions( QWidget *parent, const char *name,CDTrack *track):QW
 
   ThisTrack=track;
   ThisAudio=track->getAudioFile();
+  ThisPlayer=new AudioPlayImage(ThisAudio);
   absSize=ThisAudio->getAbsoluteDuration();
 
   this->setCaption(locale->translate("KreateCD - audio options"));
 
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
 
   mainlayout=new QVBoxLayout(this);
 
@@ -184,12 +190,12 @@ AudioOptions::AudioOptions( QWidget *parent, const char *name,CDTrack *track):QW
 
   connect(PlayButton,SIGNAL(clicked()),this,SLOT(doPlay()));
   connect(PlayBeginButton,SIGNAL(clicked()),this,SLOT(doPlayBegin()));
-  connect(StopButton,SIGNAL(clicked()),ThisAudio,SLOT(stopAudio()));
+  connect(StopButton,SIGNAL(clicked()),ThisPlayer,SLOT(stopAudio()));
   connect(ForwardButton,SIGNAL(clicked()),this,SLOT(doForward()));
   connect(BackwardButton,SIGNAL(clicked()),this,SLOT(doBackward()));
   connect(SetStartButton,SIGNAL(clicked()),this,SLOT(setStart()));
   connect(SetStopButton,SIGNAL(clicked()),this,SLOT(setStop()));
-  connect(ThisAudio,SIGNAL(audioPlayPosition(int)),
+  connect(ThisPlayer,SIGNAL(audioPlayPosition(int)),
           this,SLOT(positionChanged(int)));
   connect(PlaySlider,SIGNAL(valueChanged(int)),
           this,SLOT(sliderMove(int)));
@@ -218,10 +224,15 @@ AudioOptions::~AudioOptions(void)
  {
   KConfig *config;
   QRect SaveRect(this->pos(),this->size());
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   config->setGroup("Geometry");
   config->writeEntry("AudioOptWindowGeo",SaveRect);
-  ThisAudio->stopAudio();
+  ThisPlayer->stopAudio();
+  delete(ThisPlayer);
  }
 
 void AudioOptions::hide()
@@ -246,7 +257,7 @@ void AudioOptions::sliderPress(void)
 void AudioOptions::sliderRelease(void)
  {
   isPressed=0;
-  ThisAudio->setAudioPosition(lastPosition);
+  ThisPlayer->setAudioPosition(lastPosition);
  }
 
 
@@ -258,12 +269,12 @@ void AudioOptions::sliderMove(int frame)
 void AudioOptions::doPlay(void)
  {
   if (lastPosition==absSize) lastPosition=-1;
-  ThisAudio->playAudio(lastPosition);
+  ThisPlayer->playAudio(lastPosition);
  }
 
 void AudioOptions::doPlayBegin(void)
  {
-  ThisAudio->playAudio(-1);
+  ThisPlayer->playAudio(-1);
  }
 
 void AudioOptions::doForward(void)
@@ -271,7 +282,7 @@ void AudioOptions::doForward(void)
   if ((lastPosition+15*75)>=absSize) return;
   lastPosition+=15*75;
   PlaySlider->setValue(lastPosition);
-  ThisAudio->setAudioPosition(lastPosition);
+  ThisPlayer->setAudioPosition(lastPosition);
  }
 
 void AudioOptions::doBackward(void)
@@ -285,14 +296,14 @@ void AudioOptions::doBackward(void)
     lastPosition-=15*75;
    }
   PlaySlider->setValue(lastPosition);
-  ThisAudio->setAudioPosition(lastPosition);
+  ThisPlayer->setAudioPosition(lastPosition);
  }
 
 void AudioOptions::changeBalance(int balance)
  {
   float rbalance;
   rbalance=(float)(balance-100)/100;
-  ThisAudio->setAudioBalance(rbalance);
+  ThisPlayer->setAudioBalance(rbalance);
   ThisAudio->setBalance(rbalance);
   emit(needUpdate());
  }
@@ -301,7 +312,7 @@ void AudioOptions::changeBoost(int boost)
  {
   float rboost;
   rboost=(float) boost/100;
-  ThisAudio->setAudioBoost(rboost);
+  ThisPlayer->setAudioBoost(rboost);
   ThisAudio->setBoost(rboost);
   emit(needUpdate());
  }
