@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -40,6 +40,7 @@ class AudioOptions : public QWidget
   private:
     class CDTrack     *ThisTrack;
     class AudioFile   *ThisAudio;
+    class AudioPlayImage  *ThisPlayer;
     class QSlider     *PlaySlider;
     class QSlider     *BalanceSlider;
     class QSlider     *VolumeSlider;
