@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -17,7 +17,10 @@
 
 #include "CDTrack.h"
 #include "AudioFile.h"
-#include "DriveAccess.h"
+#include "AudioBuildImage.h"
+#include "AudioFileFormat.h"
+#include "CDParanoia.h"
+#include "DeviceRipper.h"
 #include "IsoImage.h"
 
 
@@ -56,7 +59,7 @@ CDTrack::CDTrack(KConfig *config)
   TrackImage=(enum TrackImage) config->readNumEntry("TrackImage",Image_None);
   //FIXME : for now we mark all loaded tracks as dirty
   if (TrackImage==Image_Clean) TrackImage=Image_Dirty;
-  IsTemporary=config->readNumEntry("IsTemporary",0);
+  IsTemporary=config->readBoolEntry("IsTemporary",false);
   CDTrackNum=config->readNumEntry("CDTrackNum",1);
   CDTocSum=config->readUnsignedLongNumEntry("CDTocSum",0);
 #if QT_VERSION >= 200
@@ -81,25 +84,31 @@ CDTrack::CDTrack(KConfig *config)
   ThisAudio=0;
   ThisISO=0;
 
-  if (IsTemporary==1)
+  if (IsTemporary==true)
    {
     ThisAudio=new AudioFile();
-    if (!ThisAudio->setupCDTrack(SourceFile))
      {
-      delete ThisAudio;
-      ThisAudio=0;
-      IsTemporary=0;
-      remove(SourceFile);
+      AudioFileFormat afifo(ThisAudio);
+      if (!afifo.setupCDTrack(SourceFile))
+       {
+        delete ThisAudio;
+        ThisAudio=0;
+        IsTemporary=false;
+        remove(SourceFile);
+       }
      }
    }
 
   if ( isAudio() && (TrackSource==Source_File) )
    {
     ThisAudio=new AudioFile();
-    if (!ThisAudio->identifyFile(SourceFile))
      {
-      delete(ThisAudio);
-      ThisAudio=0;
+       AudioFileFormat afifo(ThisAudio);
+       if (!afifo.identifyFile(SourceFile))
+       {
+        delete(ThisAudio);
+        ThisAudio=0;
+       }
      }
    }
   if ( isAudio() && (ThisAudio!=0) )
@@ -161,7 +170,7 @@ CDTrack::CDTrack(void)
   ThisAudio=0;
   ThisISO=0;
   TrackImage=Image_None;
-  IsTemporary=0;
+  IsTemporary=false;
   clearSource();
  }
 
@@ -214,10 +223,10 @@ void CDTrack::getTrackTypeText(char *type)
   strcpy(type,TypeNames[TrackType]);
  }
 
-int CDTrack::isAudio(void)
+bool CDTrack::isAudio(void)
  {
-  if ( (TrackType==Track_Audio) || (TrackType==Track_AudioPreEmph) ) return(1);
-  return(0);
+  if ( (TrackType==Track_Audio) || (TrackType==Track_AudioPreEmph) ) return(true);
+  return(false);
  }
 
 class AudioFile * CDTrack::getAudioFile(void)
@@ -230,26 +239,26 @@ class ISOImage * CDTrack::getISOImage(void)
   return(ThisISO);
  }
 
-int CDTrack::getBurnFile(char *burnfile)
+bool CDTrack::getBurnFile(char *burnfile)
  {
   switch (TrackImage)
    {
     case Image_None:
       strcpy (burnfile,SourceFile);
-      return(1);
+      return(true);
     case Image_Dirty:
-      return(0);
+      return(false);
     case Image_Clean:
       strcpy(burnfile,ImageFile);
-      return(1);
+      return(true);
    }
-  return(0);
+  return(false);
  }
 
-int CDTrack::getUseImage(void)
+bool CDTrack::getUseImage(void)
  {
-  if (TrackImage==Image_None) return(0);
-  return(1);
+  if (TrackImage==Image_None) return(false);
+  return(true);
  }
 
 void CDTrack::enableImage(void)
@@ -284,26 +293,6 @@ void CDTrack::getDurationHMSB(char *durstr,long int duration)
   sprintf(durstr,"%01d:%02d:%02d.%02d",hour,min,sec,block);
  }      
 
-enum CDTrack::TrackType CDTrack::getTOCType(int control,int mode)
- {
-  enum TrackType ttype;
-  ttype=Track_CDI;
-  switch (control)
-     {
-      case 0:
-        ttype=CDTrack::Track_Audio;
-        break;
-      case 1:
-        ttype=CDTrack::Track_AudioPreEmph;
-      case 4:
-        if (mode==1) ttype=CDTrack::Track_DataMode1;
-        if (mode==2) ttype=CDTrack::Track_DataMode2;
-        break;
-     }
-  return(ttype);
- }
-
-
 void CDTrack::setDescription(const char *descr)
  {
   strncpy(Description,descr,39);
@@ -339,7 +328,7 @@ void CDTrack::clearSource(void)
   if (IsTemporary)
    {
     remove(SourceFile);
-    IsTemporary=0;
+    IsTemporary=false;
    }
 
   SourceFile[0]='\0';
@@ -359,11 +348,14 @@ void CDTrack::setSourceFile(const char *filename)
   if (isAudio())
    {
     ThisAudio=new AudioFile;
-    if (!ThisAudio->identifyFile(filename))
      {
-      delete(ThisAudio);
-      ThisAudio=0;
-     }
+      AudioFileFormat afifo(ThisAudio);
+       if (!afifo.identifyFile(filename))
+       {
+        delete(ThisAudio);
+        ThisAudio=0;
+       }
+      }
     needImage();
    }
   TrackImage=NeedImage?Image_Dirty:Image_None;
@@ -419,10 +411,10 @@ void CDTrack::setSourceTrack(int track,long int tocsum,unsigned long duration,un
 void CDTrack::updateTrack()
  {
   clearImage();
-  if (IsTemporary==1)
+  if (IsTemporary==true)
    {
     remove(SourceFile);
-    IsTemporary=0;
+    IsTemporary=false;
    }
 
   switch (TrackSource)
@@ -463,41 +455,43 @@ void CDTrack::updateTrack()
      }
     case Source_Filesystem:
       break;
-    
-     
    }
-
  }
 
-int CDTrack::validateTrack(void)
+bool CDTrack::validateTrack(void)
  {
   if (TrackSource==Source_None) return(0);
-  if ((TrackSource==Source_CD) && (isAudio()) && (IsTemporary!=1))
+  if ((TrackSource==Source_CD) && (isAudio()) && (IsTemporary!=true))
    {
-    DriveAccess da;
+    AudioRipper *ripper=new CDParanoia();
     clearImage();
-    if (IsTemporary==1)
+    if (IsTemporary==true)
      {
       remove(SourceFile);
-      IsTemporary=0;
+      IsTemporary=false;
      }
-    createName(SourceFile,0,TrackDuration);
-    if (da.paranoiaTrack(CDTrackNum,SourceFile)==0)
+    createName(SourceFile,false,TrackDuration);
+    if (ripper->ripAudio(CDTrackNum,SourceFile)==0)
      {
-      return(0);
+      delete ripper;
+      return(false);
      }
-    IsTemporary=1; 
+    delete ripper;
+    IsTemporary=true;
     ThisAudio=new AudioFile;
-    if (!ThisAudio->setupCDTrack(SourceFile))
      {
-      delete ThisAudio;
-      ThisAudio=0;
-      IsTemporary=0;
-      remove(SourceFile);
-      return(0);
+      AudioFileFormat afifo(ThisAudio);
+       if (!afifo.setupCDTrack(SourceFile))
+       {
+        delete ThisAudio;
+        ThisAudio=0;
+        IsTemporary=false;
+        remove(SourceFile);
+        return(false);
+       }
      }
     updateDuration(SourceFile);
-    return(1);
+    return(true);
    }
 
   if (TrackImage==Image_None) return(1);
@@ -510,47 +504,56 @@ int CDTrack::validateTrack(void)
        {
         // create audio image file
         if (ThisAudio==NULL) return(0);
-        createName(ImageFile,1,TrackDuration);
-        if (!ThisAudio->buildImage(ImageFile))
+        createName(ImageFile,true,TrackDuration);
          {
-          return(0);
+          AudioBuildImage img(ThisAudio);
+           if (!img.buildImage(ImageFile))
+           {
+            return(false);
+           }
+
          }
         TrackImage=Image_Clean;
         updateDuration(ImageFile);
-        return(1);
+        return(true);
        }
        else
        {
         // rip a datatrack from CD
-        DriveAccess da;
-        createName(ImageFile,1,TrackDuration);
-        if (!da.readDataTrack(CDTrackNum,ImageFile,TrackLBA,TrackDuration))
+        DataRipper *datarip= new DeviceRipper();
+        createName(ImageFile,true,TrackDuration);
+        if (!datarip->readDataTrack(CDTrackNum,ImageFile,TrackLBA,TrackDuration))
          {
-          return(0);
+          delete datarip;
+          return(false);
          }
+        delete(datarip);
         updateDuration(ImageFile);
         TrackImage=Image_Clean;
-        return(1);
+        return(true);
        } 
     case Source_File:
       if (isAudio())
        {
         // create audio image file
         if (ThisAudio==NULL) return(0);
-        createName(ImageFile,1,TrackDuration);
-        if (!ThisAudio->buildImage(ImageFile))
+        createName(ImageFile,true,TrackDuration);
          {
-          return(0);
-         }
+           AudioBuildImage img(ThisAudio);
+           if (!img.buildImage(ImageFile))
+           {
+            return(false);
+           }
+          }
         updateDuration(ImageFile);
         TrackImage=Image_Clean;
-        return(1);
+        return(true);
        }
        else
        {
         // copy a datatrack
-        createName(ImageFile,1,TrackDuration);
-        return(0);
+        createName(ImageFile,true,TrackDuration);
+        return(false);
         //updateDuration(ImageFile);
         //TrackImage=Image_Clean;
         //return(1);
@@ -558,21 +561,21 @@ int CDTrack::validateTrack(void)
     case Source_Filesystem:
      {
       if (ThisISO==NULL) return(0);
-      createName(ImageFile,1,rand()%1000);
+      createName(ImageFile,true,rand()%1000);
       if (!ThisISO->makeImage(ImageFile))
        {
-        return(0);
+        return(false);
        }
       updateDuration(ImageFile);
       TrackImage=Image_Clean;
-      return(1);
+      return(true);
      }
 
     default:
-      return(0);
+      return(false);
    }
 
-  return(0);
+  return(false);
  }
 
 
@@ -584,14 +587,18 @@ void CDTrack::clearImage(void)
   ImageFile[0]='\0';
  }
 
-void CDTrack::createName(char *fn,int type,long int duration)
+void CDTrack::createName(char *fn,bool cdrimg,long int duration)
  {
   KConfig *config;
   QString tempdir;
   const char *directory;
   int random;
 
+#if QT_VERSION >=200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   config->setGroup("Path");
   tempdir=config->readEntry("PathTemporary","/tmp");
   directory=tempdir.data();
@@ -600,7 +607,7 @@ void CDTrack::createName(char *fn,int type,long int duration)
    {
     struct stat sbuf;
     random=rand()%1000;
-    sprintf(fn,"%s/kreatecd_%ld_%d.%s",directory,duration,random,type?"img":"cdt");
+    sprintf(fn,"%s/kreatecd_%ld_%d.%s",directory,duration,random,cdrimg?"img":"cdt");
     if (stat(fn,&sbuf)!=0) break;
    }
  }
@@ -628,33 +635,33 @@ void CDTrack::updateDuration(const char *fn)
  }
 
 
-int CDTrack::needImage(void)
+bool CDTrack::needImage(void)
  {
   switch (TrackSource)
    {
     case Source_None:
-      NeedImage=0;
+      NeedImage=false;
       break;
     case Source_File:
       if (ThisAudio==0)
        {
-        NeedImage=0;
+        NeedImage=false;
        }
        else
        {
-        NeedImage=ThisAudio->needImage()?1:0;
+        NeedImage=ThisAudio->needImage()?true:false;
        }
     case Source_Filesystem:
-      NeedImage=1;
+      NeedImage=true;
       break;
     case Source_CD:
       if (isAudio())
        {
-        NeedImage=0;
+        NeedImage=false;
        }
        else
        {
-        NeedImage=1;
+        NeedImage=true;
        }
    }
   return(NeedImage);
