@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -25,6 +25,8 @@
 #include <stdlib.h>
 #include <sys/stat.h>
 
+#include "pathconfig.h"
+#include "uidcontrol.h"
 
 extern KLocale *locale;
 
@@ -34,13 +36,17 @@ ConfPath::ConfPath( QWidget *parent, const char *name):QWidget(parent,name)
   QVBoxLayout *qwinlay;
   QHBoxLayout *buttonlayout;
   QGridLayout *qgrid;
-  QPushButton *parabut,*cdrbut,*mkisobut,*tmpbut;
+  QPushButton *parabut,*cdrbut,*mkisobut,*cddabut,*tmpbut;
 
   QRect DefaultRect(100,50,500,300);
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
 
   qwinlay=new QVBoxLayout(this);
-  qgrid=new QGridLayout(9,6);
+  qgrid=new QGridLayout(11,6);
   qwinlay->addStretch(1);
   qwinlay->addLayout(qgrid,10);
   qwinlay->addStretch(1);
@@ -58,9 +64,10 @@ ConfPath::ConfPath( QWidget *parent, const char *name):QWidget(parent,name)
   qgrid->setRowStretch(4,1);
   qgrid->setRowStretch(6,1);
   qgrid->setRowStretch(8,1);
+  qgrid->setRowStretch(10,1);
 
 
-  ParanoiaLabel=new QLabel(locale->translate("Path : cdparanoia"),this);
+  ParanoiaLabel=new QLabel(locale->translate("Path: cdparanoia"),this);
   ParanoiaLabel->setMinimumSize(ParanoiaLabel->sizeHint());
   ParanoiaPath=new QLineEdit(this,"paranoia path");
   ParanoiaPath->setMaxLength(39);
@@ -68,7 +75,7 @@ ConfPath::ConfPath( QWidget *parent, const char *name):QWidget(parent,name)
   qgrid->addWidget(ParanoiaLabel,1,1,AlignCenter);
   qgrid->addWidget(ParanoiaPath,1,2);
 
-  CdrecordLabel=new QLabel(locale->translate("Path : cdrecord"),this);
+  CdrecordLabel=new QLabel(locale->translate("Path: cdrecord"),this);
   CdrecordLabel->setMinimumSize(CdrecordLabel->sizeHint());
   CdrecordPath=new QLineEdit(this,"cdrecord path");
   CdrecordPath->setMaxLength(39);
@@ -76,7 +83,7 @@ ConfPath::ConfPath( QWidget *parent, const char *name):QWidget(parent,name)
   qgrid->addWidget(CdrecordLabel,3,1,AlignCenter);
   qgrid->addWidget(CdrecordPath,3,2);
 
-  IsofsLabel=new QLabel(locale->translate("Path : mkisofs"),this);
+  IsofsLabel=new QLabel(locale->translate("Path: mkisofs"),this);
   IsofsLabel->setMinimumSize(IsofsLabel->sizeHint());
   IsofsPath=new QLineEdit(this,"mkisofs path");
   IsofsPath->setMaxLength(39);
@@ -84,13 +91,21 @@ ConfPath::ConfPath( QWidget *parent, const char *name):QWidget(parent,name)
   qgrid->addWidget(IsofsLabel,5,1,AlignCenter);
   qgrid->addWidget(IsofsPath,5,2);
 
+  CddawavLabel=new QLabel(locale->translate("Path: cdda2wav"),this);
+  CddawavLabel->setMinimumSize(CddawavLabel->sizeHint());
+  CddawavPath=new QLineEdit(this,"cdda2wav path");
+  CddawavPath->setMaxLength(39);
+  CddawavPath->setMinimumSize(CddawavPath->sizeHint());
+  qgrid->addWidget(CddawavLabel,7,1,AlignCenter);
+  qgrid->addWidget(CddawavPath,7,2);
+
   TemporaryLabel=new QLabel(locale->translate("Temporary directory"),this);
   TemporaryLabel->setMinimumSize(TemporaryLabel->sizeHint());
   TemporaryPath=new QLineEdit(this,"temporary path");
   TemporaryPath->setMaxLength(39);
   TemporaryPath->setMinimumSize(TemporaryPath->sizeHint());
-  qgrid->addWidget(TemporaryLabel,7,1,AlignCenter);
-  qgrid->addWidget(TemporaryPath,7,2);
+  qgrid->addWidget(TemporaryLabel,9,1,AlignCenter);
+  qgrid->addWidget(TemporaryPath,9,2);
 
   parabut=new QPushButton("...",this);
   parabut->setFixedSize(parabut->sizeHint());
@@ -101,9 +116,12 @@ ConfPath::ConfPath( QWidget *parent, const char *name):QWidget(parent,name)
   mkisobut=new QPushButton("...",this);
   mkisobut->setFixedSize(parabut->sizeHint());
   qgrid->addWidget(mkisobut,5,4,AlignCenter);
+  cddabut=new QPushButton("...",this);
+  cddabut->setFixedSize(parabut->sizeHint());
+  qgrid->addWidget(cddabut,7,4,AlignCenter);
   tmpbut=new QPushButton("...",this);
   tmpbut->setFixedSize(parabut->sizeHint());
-  qgrid->addWidget(tmpbut,7,4,AlignCenter);
+  qgrid->addWidget(tmpbut,9,4,AlignCenter);
 
 
   buttonlayout=new QHBoxLayout();
@@ -129,17 +147,52 @@ ConfPath::ConfPath( QWidget *parent, const char *name):QWidget(parent,name)
   connect(parabut,SIGNAL(clicked()),this,SLOT(changeParanoia()));
   connect(cdrbut,SIGNAL(clicked()),this,SLOT(changeCdrecord()));
   connect(mkisobut,SIGNAL(clicked()),this,SLOT(changeMkisofs()));
+  connect(cddabut,SIGNAL(clicked()),this,SLOT(changeCddawav()));
   connect(tmpbut,SIGNAL(clicked()),this,SLOT(changeTemp()));
 
    {
     QString tstring;
     config->setGroup("Path");
-    tstring=config->readEntry("PathCdparanoia","cdparanoia");
-    ParanoiaPath->setText(tstring.data());
-    tstring=config->readEntry("PathCdrecord","cdrecord");
-    CdrecordPath->setText(tstring.data());    
-    tstring=config->readEntry("PathMkisofs","mkisofs");
-    IsofsPath->setText(tstring.data());
+    if ROOT_CALLED
+     {
+      tstring=config->readEntry("PathCdparanoia",PATH_CDPARANOIA);
+      ParanoiaPath->setText(tstring.data());
+      ParanoiaPath->setEnabled(FALSE);
+     }
+     else
+     {
+      ParanoiaPath->setText(PATH_CDPARANOIA);
+     }
+    if ROOT_CALLED
+     {
+      tstring=config->readEntry("PathCdrecord",PATH_CDRECORD);
+      CdrecordPath->setText(tstring.data());
+      CdrecordPath->setEnabled(FALSE);    
+     }
+     else
+     {
+      CdrecordPath->setText(PATH_CDRECORD);
+     }   
+    if ROOT_CALLED
+     {
+      tstring=config->readEntry("PathMkisofs",PATH_MKISOFS);
+      IsofsPath->setText(tstring.data());
+      IsofsPath->setEnabled(FALSE);
+     }
+     else
+     {
+      IsofsPath->setText(PATH_MKISOFS);
+     }
+    if ROOT_CALLED
+     {
+      tstring=config->readEntry("PathCdda2wav",PATH_CDDA2WAV);
+      CddawavPath->setText(tstring.data());
+      CddawavPath->setEnabled(FALSE);
+     }
+     else
+     {
+      CddawavPath->setText(PATH_CDDA2WAV);
+     }
     tstring=config->readEntry("PathTemporary","/tmp/");
     TemporaryPath->setText(tstring.data());
    }
@@ -155,7 +208,11 @@ ConfPath::~ConfPath(void)
  {
   KConfig *config;
   QRect SaveRect(this->pos(),this->size());
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   config->setGroup("Geometry");
   config->writeEntry("PathWindowGeo",SaveRect);
  }
@@ -163,11 +220,16 @@ ConfPath::~ConfPath(void)
 void ConfPath::applySettings(void)
  {
   KConfig *config;
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   config->setGroup("Path");
   config->writeEntry("PathCdparanoia",ParanoiaPath->text());
   config->writeEntry("PathCdrecord",CdrecordPath->text());
   config->writeEntry("PathMkisofs",IsofsPath->text());
+  config->writeEntry("PathCdda2wav",CddawavPath->text());
   config->writeEntry("PathTemporary",TemporaryPath->text());
 
  }
@@ -191,49 +253,6 @@ void ConfPath::cancelButton(void)
  }
 
 
-int ConfPath::searchPath(const char *program,char *path)
- {
-  char *pathenv;
-  char thispath[512];
-  char *sptr,*cptr;
-  struct stat statbuf;
-
-  pathenv=getenv("PATH");
-  
-  sptr=pathenv;
-  cptr=sptr;
-  do
-   {
-    if ( ( *cptr==':') || ( *cptr=='\0') )
-     {
-      strncpy(thispath,sptr,cptr-sptr);
-      thispath[cptr-sptr]='/';
-      thispath[cptr-sptr+1]=0;
-      strcat(thispath,program); 
-      if ( stat(thispath,&statbuf)==0)
-       {
-        if (path==0) return(1);
-        strcpy(path,thispath);
-        return(1);
-       }
-      sptr=cptr+1;
-     }
-    cptr++;
-   } while (*(cptr-1)!=0);
-
-  //check for /opt/schily/bin (standard install location,often not in PATH)
-
-  strcpy(thispath,"/opt/schily/bin/");
-  strcat(thispath,program);
-  if (stat(thispath,&statbuf)==0)
-   {
-    if (path==0) return(1);
-    strcpy(path,thispath);
-    return(1);
-   }
-  return(0);
- }
-
 int ConfPath::verifyPrograms(void)
  {
   int retv=1;
@@ -241,52 +260,39 @@ int ConfPath::verifyPrograms(void)
   QString progqs;
   KConfig *config;
   struct stat statbuf;
-  char temppath[256];
 
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   config->setGroup("Path");
-  progqs=config->readEntry("PathCdrecord","");
+  progqs=config->readEntry("PathCdrecord",PATH_CDRECORD);
   prog=progqs.data();
   if ( (prog[0]==0) || (stat(prog,&statbuf)!=0) )
    {
-    if (searchPath("cdrecord",temppath)==0)
-     {
-      retv=0;
-     }
-     else
-     {
-      config->writeEntry("PathCdrecord",temppath);
-     }    
+    retv=0;
    }
 
-  config=kapp->getConfig();
-  progqs=config->readEntry("PathCdparanoia","");
+  progqs=config->readEntry("PathCdparanoia",PATH_CDPARANOIA);
   prog=progqs.data();
   if ( (prog[0]==0) || (stat(prog,&statbuf)!=0) )
    {
-    if (searchPath("cdparanoia",temppath)==0)
-     {
-      retv=0;
-     }
-     else
-     {
-      config->writeEntry("PathCdparanoia",temppath);
-     }    
+    retv=0;
    }
 
-  config=kapp->getConfig();
-  progqs=config->readEntry("PathMkisofs","");
+  progqs=config->readEntry("PathMkisofs",PATH_MKISOFS);
   prog=progqs.data();
   if ( (prog[0]==0) || (stat(prog,&statbuf)!=0) )
    {
-    if (searchPath("mkisofs",temppath)==0)
-     {
-      retv=0;
-     }
-     else
-     {
-      config->writeEntry("PathMkisofs",temppath);
-     }    
+    retv=0;
+   }
+
+  progqs=config->readEntry("PathCdda2wav",PATH_CDDA2WAV);
+  prog=progqs.data();
+  if ( (prog[0]==0) || (stat(prog,&statbuf)!=0) )
+   {
+    retv=0;
    }
 
   progqs=config->readEntry("PathTemporary","");
@@ -304,7 +310,7 @@ void ConfPath::changeParanoia(void)
  {
   QString openname;
 #if QT_VERSION >= 200
-  openname=KFileDialog::getOpenFileName(ParanoiaPath->text(),"*",this,locale->translate("Select location of cdparanoia"));
+  openname=KFileDialog::getOpenURL(ParanoiaPath->text(),"*",this,locale->translate("Select location of cdparanoia")).path();
   KURL::decode(openname);
 #else
   openname=KFileDialog::getOpenFileName(ParanoiaPath->text(),"*",this,locale->translate("Select location of cdparanoia"));
@@ -318,7 +324,7 @@ void ConfPath::changeCdrecord(void)
  {
   QString openname;
 #if QT_VERSION >= 200
-  openname=KFileDialog::getOpenFileName(CdrecordPath->text(),"*",this,locale->translate("Select location of cdrecord"));
+  openname=KFileDialog::getOpenURL(CdrecordPath->text(),"*",this,locale->translate("Select location of cdrecord")).path();
   KURL::decode(openname);
 #else
   openname=KFileDialog::getOpenFileName(CdrecordPath->text(),"*",this,locale->translate("Select location of cdrecord"));
@@ -332,7 +338,7 @@ void ConfPath::changeMkisofs(void)
  {
   QString openname;
 #if QT_VERSION >= 200
-  openname=KFileDialog::getOpenFileName(IsofsPath->text(),"*",this,locale->translate("Select location of mkisofs"));
+  openname=KFileDialog::getOpenURL(IsofsPath->text(),"*",this,locale->translate("Select location of mkisofs")).path();
   KURL::decode(openname);
 #else
   openname=KFileDialog::getOpenFileName(IsofsPath->text(),"*",this,locale->translate("Select location of mkisofs"));
@@ -342,11 +348,25 @@ void ConfPath::changeMkisofs(void)
   IsofsPath->setText(openname);
  }
 
+void ConfPath::changeCddawav(void)
+ {
+  QString openname;
+#if QT_VERSION >= 200
+  openname=KFileDialog::getOpenURL(CddawavPath->text(),"*",this,locale->translate("Select location of cdda2wav")).path();
+  KURL::decode(openname);
+#else
+  openname=KFileDialog::getOpenFileName(CddawavPath->text(),"*",this,locale->translate("Select location of cdda2wav"));
+  KURL::decodeURL(openname);
+#endif
+  if (openname.isEmpty()) return;
+  CddawavPath->setText(openname);
+ }
+
 void ConfPath::changeTemp(void)
  {
   QString openname;
 #if QT_VERSION >= 200
-  openname=KFileDialog::getOpenFileName(TemporaryPath->text(),"*",this,locale->translate("Select temporary directory"));
+  openname=KFileDialog::getOpenURL(TemporaryPath->text(),"*",this,locale->translate("Select temporary directory")).path();
   KURL::decode(openname);
 #else
   openname=KFileDialog::getOpenFileName(TemporaryPath->text(),"*",this,locale->translate("Select temporary directory"));
