@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -29,19 +29,20 @@ class ConfPath : public QWidget
          void changeParanoia(void);
          void changeCdrecord(void);
          void changeMkisofs(void);
+         void changeCddawav(void);
          void changeTemp(void);
 
   private:
-    static int  searchPath(const char *program,char *path=0);
-
     class QLineEdit   *ParanoiaPath;
     class QLineEdit   *IsofsPath;
     class QLineEdit   *CdrecordPath;
+    class QLineEdit   *CddawavPath;
     class QLineEdit   *TemporaryPath;
 
     class QLabel   *ParanoiaLabel;
     class QLabel   *IsofsLabel;
     class QLabel   *CdrecordLabel;
+    class QLabel   *CddawavLabel;
     class QLabel   *TemporaryLabel;
 
     class QPushButton  *okbutton;
