@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -40,9 +40,11 @@ ConfSCSI::ConfSCSI( QWidget *parent, const char *name):QWidget(parent,name)
   QHBoxLayout  *buttonlayout;
 
  
-
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
-
+#endif
 
   config->setGroup("SCSI");
   writer_id=config->readNumEntry("SCSIWriterUnit",-1);
@@ -56,7 +58,7 @@ ConfSCSI::ConfSCSI( QWidget *parent, const char *name):QWidget(parent,name)
 
   mainlayout=new QVBoxLayout(this);
 
-  SCSIBus=new DriveAccess();
+  SCSIBus=new BusScanner();
   SCSIBus->scanSCSIBus();
 
   scsiboxes[0]=new QButtonGroup(locale->translate("CD writer"),this,"writer group");
@@ -200,7 +202,11 @@ ConfSCSI::~ConfSCSI(void)
  {
   KConfig *config;
   QRect SaveRect(this->pos(),this->size());
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   config->setGroup("Geometry");
   config->writeEntry("SCSIWindowGeo",SaveRect);
   delete (SCSIBus);
@@ -209,7 +215,11 @@ ConfSCSI::~ConfSCSI(void)
 void ConfSCSI::applySettings(void)
  {
   KConfig *config;
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   config->setGroup("SCSI");
   config->writeEntry("SCSIWriterHost",writer_host);
   config->writeEntry("SCSIWriterUnit",writer_id);
