@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -8,7 +8,7 @@
 
 #include <qwidget.h>
 
-#include "DriveAccess.h"
+#include "BusScanner.h"
 
 class ConfSCSI : public QWidget
  {
@@ -47,7 +47,7 @@ class ConfSCSI : public QWidget
     class QSpinBox   *writerhostspin;
     class QSpinBox   *cdromhostspin;
 
-    class DriveAccess  *SCSIBus;
+    class BusScanner  *SCSIBus;
 
     char scsidevs[MAX_SCSI_HOSTS][MAX_SCSI_UNITS][32];
     
