@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General
 // Public License.  See the file COPYING in the main directory of the
@@ -11,8 +11,8 @@
 
 #include <qobject.h>
 #include <qlistview.h>
-#include <kfileinfo.h>
-#include <kdir.h>
+#include <qfileinfo.h>
+#include <qdir.h>
 #include <kapp.h>
 #include <klocale.h>
 #include <kiconloader.h>
@@ -50,7 +50,7 @@ void FileTreeItem::setupISOFile(ISOFile *isofile)
 
   if (isoFile->type()==ISOFile::ISO_RealDir)
    {
-    fileObject=new KFileInfo(isoFile->reference()->data(),"");
+    fileObject=new QFileInfo(isoFile->reference()->data());
     setupDirObject();
    }
 
@@ -116,24 +116,24 @@ FileTreeItem::FileTreeItem(FileTreeItem *parent):QListViewItem(parent)
 
 
 
-FileTreeItem::FileTreeItem(KFileInfo *fileinfo,FileTree *parent):QListViewItem(parent)
+FileTreeItem::FileTreeItem(QFileInfo *fileinfo,FileTree *parent):QListViewItem(parent)
  {
   parentItem=0;
-  setupKFileInfo(fileinfo);
+  setupQFileInfo(fileinfo);
  }
 
-FileTreeItem::FileTreeItem(KFileInfo *fileinfo,FileTreeItem *parent):QListViewItem(parent)
+FileTreeItem::FileTreeItem(QFileInfo *fileinfo,FileTreeItem *parent):QListViewItem(parent)
  {
   parentItem=parent;
-  setupKFileInfo(fileinfo);
+  setupQFileInfo(fileinfo);
  }
 
 
-void FileTreeItem::setupKFileInfo(KFileInfo *fileinfo)
+void FileTreeItem::setupQFileInfo(QFileInfo *fileinfo)
  {
   QPixmap pmap;
 
-  fileObject=new KFileInfo(*fileinfo);
+  fileObject=new QFileInfo(*fileinfo);
   fileList=new FileTreeItems();
   isoFile=0;
   dummyItem=0;
@@ -184,7 +184,7 @@ void FileTreeItem::setupKFileInfo(KFileInfo *fileinfo)
 
   if (strcmp("",fileObject->fileName())==0)
    {
-    this->setText(0,fileObject->absURL());
+    this->setText(0,fileObject->absFilePath());
    }
    else
    {
@@ -213,12 +213,7 @@ void FileTreeItem::setupDirObject(void)
   if ( (fileObject->isDir()) && (fileObject->isReadable()) )
    {
     QString filename;
-    getFilename(&filename,fileObject);
-    dirObject=new KDir(filename);
-    connect(dirObject,SIGNAL(newFilesArrived(const KFileInfoList *)),
-            this,SLOT(newFiles(const KFileInfoList *)));
-    connect(dirObject,SIGNAL(finished()),
-            this,SLOT(dropDummy()));
+    dirObject=new QDir(fileObject->absFilePath());
    }
    else
    {
@@ -257,7 +252,7 @@ void FileTreeItem::expandTree(void)
    }
   if (dirObject==0) return;
   newFiles(dirObject->entryInfoList());
-  if (dirObject->isFinished()) dropDummy();
+  dropDummy();
   isDirExpanded=true;
  }
 
@@ -317,13 +312,13 @@ void FileTreeItem::collapseSubTree(void)
 
 
 
-void FileTreeItem::newFiles(const KFileInfoList *infos)
+void FileTreeItem::newFiles(const QFileInfoList *infos)
  {
-  KFileInfoList *infolist;
-  KFileInfo *info;
+  QFileInfoList *infolist;
+  QFileInfo *info;
   FileTreeItem *item;
 
-  infolist=new KFileInfoList(*infos);
+  infolist=new QFileInfoList(*infos);
   info=infolist->first();
   while (info!=0)
    {
@@ -340,30 +335,10 @@ void FileTreeItem::newFiles(const KFileInfoList *infos)
  }
 
 
-void FileTreeItem::getFilename(QString *fname,KFileInfo *finfo)
- {
-  *fname=finfo->absURL();
-  if (strcmp(finfo->absURL().data(),"//")==0)
-   {
-    *fname="/";
-    *fname+=finfo->fileName();
-   }
-   else
-   {
-    QString tmp;
-    *fname=finfo->absURL();
-    tmp=fname->right(2);
-    while (tmp=fname->right(2),strcmp(tmp.data(),"//")==0) {
-      fname->truncate(fname->length()-1);
-     }
-    *fname+=finfo->fileName();
-   }
- }
-
 bool FileTreeItem::fileName(QString *filename)
  {
   if (fileObject==0) return (false);
-  getFilename(filename,fileObject);
+  *filename=fileObject->absFilePath();
   return(true);
  }
 
@@ -465,7 +440,7 @@ void FileTree::changeSelect(QListViewItem *sitem)
   currentItem=(FileTreeItem *) sitem;
  }
 
-void FileTree::addDir(KFileInfo *finfo)
+void FileTree::addDir(QFileInfo *finfo)
  {
   FileTreeItem *item;
 
@@ -503,32 +478,15 @@ bool FileTree::deleteObject(void)
 
 bool FileTree::addRealObject(QString *fname)
  {
-  QString path;
-  QString file;
   QString complete;
+  QString file;
 
-  KFileInfo *kfi;
+  QFileInfo *kfi;
   ISOFile::ISOType itype;
-  int index;
   ISOFile *ifil;
 
-  path=fname->data();
-  file=fname->data();
   if (currentItem==0) return(false);
-
-  index=fname->findRev('/');
-  if (index==-1) return(false);
-  path.remove(index+1,file.length()-(index+1));
-  file.remove(0,index+1);
-  if (strcmp(path.right(2).data(),"//")==0)
-   {
-    path.truncate(path.length()-1);
-   }
-  if (strcmp(path.right(1).data(),"/")!=0)
-   {
-    path+="/";
-   }
-  kfi=new KFileInfo(path,file);
+  kfi=new QFileInfo(fname->data());
   if (kfi==0) return(false);
 
   if (!kfi->isReadable())
@@ -547,8 +505,8 @@ bool FileTree::addRealObject(QString *fname)
    }
 
 
-  complete=path.data();
-  complete+=file.data();
+  complete=fname->data();
+  file=kfi->fileName();
 
   ifil=new ISOFile(itype,&file,&complete);
 
