@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General
 // Public License.  See the file COPYING in the main directory of the
@@ -10,8 +10,8 @@
 #include <qpixmap.h>
 
 #include <qlistview.h>
-#include <kfileinfocontents.h>
-#include <kfileinfo.h>
+#include <qfileinfo.h>
+#include <qdir.h>
 
 class FileTree;
 class FileTreeItem;
@@ -22,8 +22,8 @@ class FileTreeItem : public QObject, public QListViewItem
   Q_OBJECT
 
   public:
-    FileTreeItem(KFileInfo *fileinfo,FileTreeItem *parent);
-    FileTreeItem(KFileInfo *fileinfo,FileTree *parent);
+    FileTreeItem(QFileInfo *fileinfo,FileTreeItem *parent);
+    FileTreeItem(QFileInfo *fileinfo,FileTree *parent);
     FileTreeItem(ISOFile   *isofile,FileTreeItem *parent);
     FileTreeItem(ISOFile   *isofile,FileTree *parent);
     FileTreeItem(FileTreeItem *parent);
@@ -43,18 +43,17 @@ class FileTreeItem : public QObject, public QListViewItem
     void collapseSubTree(void);
 
   private slots:
-    void newFiles(const KFileInfoList *infos);
+    void newFiles(const QFileInfoList *infos);
     void dropDummy(void);
 
   private:
     void setupISOFile(ISOFile *isofile);
-    void setupKFileInfo(KFileInfo *fileinfo);
+    void setupQFileInfo(QFileInfo *fileinfo);
 
-    void getFilename(class QString *fname,class KFileInfo *finfo);
     void setupDirObject(void);
 
-    KFileInfo            *fileObject;
-    KDir                 *dirObject;
+    QFileInfo            *fileObject;
+    QDir                 *dirObject;
     QList<FileTreeItem>  *fileList;
     ISOFile              *isoFile;
     bool                  isDirExpanded;
@@ -70,7 +69,7 @@ class FileTree : public QListView
   public:
     FileTree(QWidget *parent=0,const char *name=0);
     ~FileTree(void);
-    void addDir(KFileInfo *finfo);
+    void addDir(QFileInfo *finfo);
     void addDir(ISOFile   *isofile);
 
     bool addRealObject(QString *fname);
