@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General
 // Public License.  See the file COPYING in the main directory of the
@@ -9,7 +9,7 @@
 #include <qobject.h>
 #include <kprocess.h>
 
-class AudioFile;
+class AudioFileOp;
 
 class Fork : public KProcess
  {
@@ -17,20 +17,20 @@ class Fork : public KProcess
 
   public:
   Fork(int (*fx)(int argc,char **argv));
-  Fork(int (*fx)(AudioFile *afi,const char *fn),AudioFile *afil,const char *fnx);
-
-  bool start(enum KProcess::RunMode, enum KProcess::Communication);
+  Fork(int (*fx)(AudioFileOp *afi,const char *fn),AudioFileOp *afil,const char *fnx);
 
+  bool start(RunMode, Communication);
+  
   bool writeStdIn(char *buffer,int bufflen);
 
   private:
   int (*function)(int argc,char **argv);
 
-  int (*function_af1)(AudioFile *afi,const char *fn);
+  int (*function_af1)(AudioFileOp *afi,const char *fn);
 
 
   int fmode;
-  AudioFile *AFile;
+  AudioFileOp *AFile;
 
 
   char strarg[1024];
