@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General
 // Public License.  See the file COPYING in the main directory of the
@@ -10,6 +10,7 @@
 #include "IsoFile.h"
 #include "ProgressDialog.h"
 #include "uidcontrol.h"
+#include "pathconfig.h"
 
 #include <kapp.h>
 #include <kconfig.h>
@@ -49,7 +50,11 @@ ISOImage::ISOImage(void)
   rootObject=new ISOFile(ISOFile::ISO_ISODir,&qs);
   fileTree=0;
 
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   config->setGroup("ISOOptions");
   loadConfig(config);
  }
@@ -128,7 +133,11 @@ bool ISOImage::buildImageTree(void)
 
   if (fileTree!=0) clearImageTree();
 
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   config->setGroup("Path");
 
   while (i<500)
@@ -426,46 +435,48 @@ const char *ISOImage::getVolumeID(void)
 bool ISOImage::makeImage(const char *filename)
  {
   int retval;
-  KProcess *mkiproc;
   KConfig *config;
 
 
-  mkiproc=new KProcess();
+  prepareProcess();
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   config->setGroup("Path");
-  *mkiproc<<config->readEntry("PathMkisofs","mkisofs");
+  if ROOT_CALLED
+   {
+    *this<<config->readEntry("PathMkisofs",PATH_MKISOFS);
+   }
+   else
+   {
+    *this<<PATH_MKISOFS;
+   }
+  
+  if (allFiles) *this<<"-no-bak";
+  if (omitTrailingDot) *this<<"-d";
+  if (noDeepRelocation) *this<<"-D";
+  if (longISONames) *this<<"-l";
+  if (allowLeadingDot) *this<<"-L";
+  if (omitVersions) *this<<"-N";
+  if (withRockRidge) *this<<"-R";
+  if (withAnonymousRockRidge) *this<<"-r";
+  if (makeTransTab) *this<<"-T";
+  if (withJoliet) *this<<"-J";
 
-  if (allFiles) *mkiproc<<"-a";
-  if (omitTrailingDot) *mkiproc<<"-d";
-  if (noDeepRelocation) *mkiproc<<"-D";
-  if (longISONames) *mkiproc<<"-l";
-  if (allowLeadingDot) *mkiproc<<"-L";
-  if (omitVersions) *mkiproc<<"-N";
-  if (withRockRidge) *mkiproc<<"-R";
-  if (withAnonymousRockRidge) *mkiproc<<"-r";
-  if (makeTransTab) *mkiproc<<"-T";
-  if (withJoliet) *mkiproc<<"-J";
+  *this<<"-o"<<filename;
+  *this<<"-f"; // always follow symbolic links
 
-  *mkiproc<<"-o"<<filename;
-  *mkiproc<<"-f"; // always follow symbolic links
+  if (applicationID[0]!=0) *this<<"-A"<<applicationID;
+  if (publisherID[0]!=0) *this<<"-P"<<publisherID;
+  if (preparerID[0]!=0) *this<<"-p"<<preparerID;
+  if (volumeID[0]!=0) *this<<"-V"<<volumeID;
+  if (systemID[0]!=0) *this<<"-sysid"<<systemID;
 
-  if (applicationID[0]!=0) *mkiproc<<"-A"<<applicationID;
-  if (publisherID[0]!=0) *mkiproc<<"-P"<<publisherID;
-  if (preparerID[0]!=0) *mkiproc<<"-p"<<preparerID;
-  if (volumeID[0]!=0) *mkiproc<<"-V"<<volumeID;
-  if (systemID[0]!=0) *mkiproc<<"-sysid"<<systemID;
 
-  linebuffer[0]='\0';
-
-  connect(mkiproc,SIGNAL(receivedStderr(KProcess *,char *,int)),
-          this,SLOT(getIsofs(KProcess *,char *,int)));
-  connect(mkiproc,SIGNAL(receivedStdout(KProcess *,char *,int)),
-          this,SLOT(getIsofs(KProcess *,char *,int)));
-  connect(mkiproc,SIGNAL(processExited(KProcess *)),
-          this,SLOT(leaveIsofs(KProcess *)));
-
-  isoprogress=new ProgressDialog(0,0,locale->translate("Creating directory tree..."),false);
-  isoprogress->show();
+  setWorkText(locale->translate("Creating directory tree..."));
+  showDialog();
 
   if (!buildImageTree())
    {
@@ -474,24 +485,15 @@ bool ISOImage::makeImage(const char *filename)
 #else
     QMessageBox::critical(0,0,locale->translate("Unable to build directory tree!"));
 #endif
-    delete(mkiproc);
-    delete(isoprogress);
+    closeProcess();
     return(false);
    }
-  delete(isoprogress);
-  isoprogress=new ProgressDialog(0,0,locale->translate("Creating ISO 9660 image ..."));
-  connect(isoprogress,SIGNAL(canceled()),isoprogress,SLOT(abortCancel()));
-
-
-  *mkiproc<<(fileTree->data());
-
+  setWorkText(locale->translate("Creating ISO 9660 image..."));
+  *this<<(fileTree->data());
   isoflag=0;
-  mkiproc->start(KProcess::NotifyOnExit,KProcess::AllOutput);
+  retval=startProcess(false);   // 1=ripping was OK  -1=abort -2=ripping error  0=window hard closed
 
-  retval=isoprogress->exec();  // 1=ripping was OK  -1=abort -2=ripping error  0=window hard closed
-
-  delete(isoprogress);
-  isoprogress=new ProgressDialog(0,0,locale->translate("Cleaning up directory tree ..."),false);
+  setWorkText(locale->translate("Cleaning up directory tree..."));
   if (!clearImageTree())
    {
 #if QT_VERSION >= 200
@@ -511,59 +513,34 @@ bool ISOImage::makeImage(const char *filename)
 #endif
    }
 
-  delete (mkiproc);
-  delete (isoprogress);
+  closeProcess();
 
   if (retval!=1) return(false);
 
   return(true);
  }
 
-void ISOImage::leaveIsofs(KProcess *)
+int ISOImage::processExited(void)
  {
-  isoprogress->abortDialog(isoflag?1:-2);
+  return(isoflag?1:-2);
  }
 
-void ISOImage::getIsofs(KProcess *,char *buffer,int bufflen)
+bool ISOImage::processStderrLine(char *linebuffer)
  {
-  int i;
-  char *buf,*buf2;
+   if (strstr(linebuffer,"done, estimate finish")!=0)
+    {
+     unsigned long fin;
+     fin=strtoul(linebuffer,0,10);
+     setProgress(fin,100,true);
+     return(true);
+    }
 
-  i=bufflen;
-  buf=buffer;
-  buf2=linebuffer;
-  while (*buf2!=0) ++buf2;
-  while (i>0)
-   {
-    if ( (*buf=='\n') || (*buf=='\r') )
-     {
-      *buf2=0;
-      buf2=linebuffer;
-      if (strstr(linebuffer,"done, estimate finish")!=0)
-       {
-        unsigned long fin;
-        fin=strtoul(linebuffer,0,10);
-        isoprogress->setProgress(fin,100);
-        goto ignLine;
-       }
-
-      if (strstr(linebuffer,"extents written")!=0)
-       {
-        isoflag=1;
-        goto ignLine;
-       }
-
-      ignLine:
-      *buf2=0;
-     }
-     else
-     {
-      *(buf2++)=*buf;
-      *buf2=0;
-     }
-    ++buf;
-    --i;
-   }
+   if (strstr(linebuffer,"extents written")!=0)
+    {
+     isoflag=1;
+     return(true);
+    }
+  return(true);
  }
 
 void ISOImage::saveImage(KConfig *config)
