@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General
 // Public License.  See the file COPYING in the main directory of the
@@ -13,7 +13,9 @@ class KProcess;
 
 #include <qobject.h>
 
-class ISOImage : public QObject
+#include "ProcessInterface.h"
+
+class ISOImage : public ProcessInterface
  {
   Q_OBJECT
   public:
@@ -85,8 +87,8 @@ class ISOImage : public QObject
     void setSystemID(const QString &id);
 
   protected slots:
-    void leaveIsofs(KProcess *process);
-    void getIsofs(KProcess *process,char *buffer,int bufflen);
+    virtual int  processExited(void);
+    virtual bool processStderrLine(char *buffer);
 
 
 
@@ -119,10 +121,6 @@ class ISOImage : public QObject
     bool             withJoliet;
     bool             allFiles;
 
-    class ProgressDialog *isoprogress;
-
-    char             linebuffer[256];
-
     int              isoflag;
  };
 
