@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -49,7 +49,11 @@ ISOOptions::ISOOptions( QWidget *parent, const char *name,ISOImage *track):QWidg
 
   this->setCaption(locale->translate("KreateCD - ISO image options"));
 
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
 
   mainlayout=new QVBoxLayout(this);
 
@@ -321,7 +325,11 @@ ISOOptions::~ISOOptions(void)
    else
    {
     QRect SaveRect(this->pos(),this->size());
+#if QT_VERSION >= 200
+    config=kapp->config();
+#else
     config=kapp->getConfig();
+#endif
     config->setGroup("Geometry");
     config->writeEntry("IsoOptWindowGeo",SaveRect);
    }
@@ -403,7 +411,11 @@ void ISOOptions::configOK(void)
 void ISOOptions::configApply(void)
  {
   KConfig *config;
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   config->setGroup("ISOOptions");
   iso->saveConfig(config);
  }
