@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -14,11 +14,11 @@
 
 #include <qlayout.h>
 #include <qpushbutton.h>
+#include <qfileinfo.h>
 
 #include <kconfig.h>
 #include <kapp.h>
 #include <klocale.h>
-#include <kfileinfo.h>
 
 
 extern KLocale *locale;
@@ -38,7 +38,11 @@ ISOWindow::ISOWindow( QWidget *parent, const char *name,ISOImage *isoimage):QWid
   QPushButton *okButton,*cancelButton;
 
   isoImage=isoimage;
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   setCaption(locale->translate("KreateCD - ISO tree window"));
 
   toplayout=new QVBoxLayout(this);
@@ -111,8 +115,8 @@ ISOWindow::ISOWindow( QWidget *parent, const char *name,ISOImage *isoimage):QWid
   // setup file trees
 
    {
-    KFileInfo *kfi;
-    kfi=new KFileInfo("/","");
+    QFileInfo *kfi;
+    kfi=new QFileInfo("/");
     sourceTree->addDir(kfi);
     delete(kfi);
    }
@@ -137,7 +141,11 @@ ISOWindow::~ISOWindow(void)
  {
   KConfig *config;
   QRect SaveRect(this->pos(),this->size());
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   config->setGroup("Geometry");
   config->writeEntry("ISOWindowGeo",SaveRect);
   delete backupTree;
