@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -8,7 +8,11 @@
 
 #include "LineDialog.h"
 
+#if QT_VERSION >= 200
+#include <klineedit.h>
+#else
 #include <klined.h>
+#endif
 
 #include <qlayout.h>
 #include <qwindowdefs.h>
