@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -14,6 +14,7 @@
 #include "WriteDialog.h"
 #include "AudioFile.h"
 #include "IsoOptions.h"
+#include "CDRWBlank.h"
 
 #include <qwidget.h>
 #include <qpushbutton.h>
@@ -49,7 +50,11 @@ MainWindow::~MainWindow(void)
   QRect SaveRect(this->pos(),this->size());
 
   readColWidth();
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   config->setGroup("Geometry");
   config->writeEntry("MainWindowGeo",SaveRect);
   config->writeEntry("MainWindowTrackWidth",Colwidth[0]);
@@ -75,7 +80,6 @@ MainWindow::~MainWindow(void)
 MainWindow::MainWindow(QWidget *parent, const char *name):QWidget(parent,name)
  {
   KConfig *config;  
-  QRect DefaultRect(100,100,500,300);
 
   QVBoxLayout *mainlayout;
   QGridLayout *trackbuttons;
@@ -99,45 +103,15 @@ MainWindow::MainWindow(QWidget *parent, const char *name):QWidget(parent,name)
      }
    }  
 
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
 
   this->setCaption(locale->translate("KreateCD - project window"));
 
-
-  MWMenu=new KMenuBar(this,"kreatecd menu");
-  QPopupMenu *filemenu=new QPopupMenu;
-  filemenu->insertItem(locale->translate("New project ..."),this,SLOT(newProject()));
-  filemenu->insertItem(locale->translate("Open project ..."),this,SLOT(openProject()));
-  filemenu->insertSeparator();
-  filemenu->insertItem(locale->translate("Save project"),this,SLOT(saveProject()));
-  filemenu->insertItem(locale->translate("Save project as ..."),this,SLOT(saveProjectAs()));
-  filemenu->insertSeparator();
-  filemenu->insertItem(locale->translate("Quit"),kapp,SLOT(quit()));
-  MWMenu->insertItem(locale->translate("File"),filemenu);
-  QPopupMenu *toolsmenu=new QPopupMenu;
-  toolsmenu->insertItem(locale->translate("&Copy CDROM ..."),this,SLOT(setupCopy()));
-  QPopupMenu *audiomenu=new QPopupMenu;
-  audiomenu->insertItem(locale->translate("Normalize to maximum"),this,SLOT(normalizeMax()));
-  audiomenu->insertItem(locale->translate("Normalize all to same"),this,SLOT(normalizeAllSame()));
-  toolsmenu->insertItem(locale->translate("Audio"),audiomenu);
-
-  MWMenu->insertItem(locale->translate("&Tools"),toolsmenu);
-  QPopupMenu *configmenu=new QPopupMenu;
-  configmenu->insertItem(locale->translate("SCSI ..."),this,SLOT(configSCSI()));
-  configmenu->insertItem(locale->translate("Paths ..."),this,SLOT(configPath()));
-  configmenu->insertItem(locale->translate("ISO 9660 ..."),this,SLOT(configISO()));
-  MWMenu->insertItem(locale->translate("Configure"),configmenu);
-  MWMenu->insertSeparator();
-  QPopupMenu *helpmenu=new QPopupMenu;
-  helpmenu->insertItem(locale->translate("Contents"),this,SLOT(helpContents()),Key_F1,-1);
-  helpmenu->insertSeparator();
-  helpmenu->insertItem(locale->translate("About KreateCD ..."),this,SLOT(helpAboutMe()));
-  MWMenu->insertItem(locale->translate("Help"),helpmenu);
-  
-
-  MainWidget=new QWidget(this);
-
-  mainlayout=new QVBoxLayout(MainWidget);
+  mainlayout=new QVBoxLayout(this);
   config->setGroup("Geometry");  
   Colwidth[0]=config->readNumEntry("MainWindowTrackWidth",8);
   Colwidth[1]=config->readNumEntry("MainWindowDescriptionWidth",60);
@@ -147,7 +121,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name):QWidget(parent,name)
   
 
 
-  MWTracklist=new QListView(MainWidget,"Track selection list");
+  MWTracklist=new QListView(this,"Track selection list");
   MWTracklist->addColumn(locale->translate("Track"),-1);
   MWTracklist->addColumn(locale->translate("Description"),-1);
   MWTracklist->addColumn(locale->translate("Size"),-1);
@@ -156,7 +130,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name):QWidget(parent,name)
   MWTracklist->setMinimumSize(MWTracklist->sizeHint());
   mainlayout->addWidget(MWTracklist,10);
 
-  SumLabel=new QLabel("-",MainWidget);
+  SumLabel=new QLabel("-",this);
   SumLabel->setFrameStyle(QFrame::Box|QFrame::Sunken);
   SumLabel->setMinimumSize(SumLabel->sizeHint());
   SumLabel->setFixedHeight(SumLabel->sizeHint().height()); 
@@ -165,22 +139,22 @@ MainWindow::MainWindow(QWidget *parent, const char *name):QWidget(parent,name)
   trackbuttons=new QGridLayout(2,3);
   mainlayout->addLayout(trackbuttons,0);
 
-  MWAddTrack=new QPushButton(locale->translate("Add track"),MainWidget,"add track");
+  MWAddTrack=new QPushButton(locale->translate("Add track"),this,"add track");
   MWAddTrack->setMinimumSize(MWAddTrack->sizeHint());
   trackbuttons->addWidget(MWAddTrack,0,0);
-  MWEditTrack=new QPushButton(locale->translate("Edit track"),MainWidget,"edit track");
+  MWEditTrack=new QPushButton(locale->translate("Edit track"),this,"edit track");
   MWEditTrack->setMinimumSize(MWEditTrack->sizeHint());
   trackbuttons->addWidget(MWEditTrack,0,1);
-  MWDeleteTrack=new QPushButton(locale->translate("Delete track"),MainWidget,"delete track");
+  MWDeleteTrack=new QPushButton(locale->translate("Delete track"),this,"delete track");
   MWDeleteTrack->setMinimumSize(MWDeleteTrack->sizeHint());
   trackbuttons->addWidget(MWDeleteTrack,0,2);
-  MWTrackUp=new QPushButton(locale->translate("Track up"),MainWidget,"track up");
+  MWTrackUp=new QPushButton(locale->translate("Track up"),this,"track up");
   MWTrackUp->setMinimumSize(MWTrackUp->sizeHint());
   trackbuttons->addWidget(MWTrackUp,1,0);
-  MWTrackUpdate=new QPushButton(locale->translate("Track update"),MainWidget,"track update");
+  MWTrackUpdate=new QPushButton(locale->translate("Track update"),this,"track update");
   MWTrackUpdate->setMinimumSize(MWTrackUpdate->sizeHint());
   trackbuttons->addWidget(MWTrackUpdate,1,1);
-  MWTrackDown=new QPushButton(locale->translate("Track down"),MainWidget,"track down");
+  MWTrackDown=new QPushButton(locale->translate("Track down"),this,"track down");
   MWTrackDown->setMinimumSize(MWTrackDown->sizeHint());
   trackbuttons->addWidget(MWTrackDown,1,2);
   trackbuttons->setColStretch(0,1);
@@ -195,7 +169,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name):QWidget(parent,name)
   mainlayout->addLayout(projectbuttons,0);
 
   projectbuttons->addStretch(1);
-  MWWriteCD=new QPushButton(locale->translate("Write CD!!"),MainWidget,"write cd");
+  MWWriteCD=new QPushButton(locale->translate("Write CD!!"),this,"write cd");
   MWWriteCD->setFixedSize(MWWriteCD->sizeHint());
   projectbuttons->addWidget(MWWriteCD,0);
   projectbuttons->addStretch(1);
@@ -209,7 +183,6 @@ MainWindow::MainWindow(QWidget *parent, const char *name):QWidget(parent,name)
   connect(MWTrackUp,SIGNAL(clicked()),this,SLOT(moveUp()));
   connect(MWTrackUpdate,SIGNAL(clicked()),this,SLOT(updateTrack()));
   connect(MWTrackDown,SIGNAL(clicked()),this,SLOT(moveDown()));
-  connect(MWMenu,SIGNAL(moved(menuPosition)),this,SLOT(menuMoved()));
   connect(MWTracklist,SIGNAL(selectionChanged(QListViewItem *)),this,SLOT(changeCurrent(QListViewItem *)));
   connect(MWTracklist,SIGNAL(doubleClicked(QListViewItem *)),this,SLOT(editTrack()));
 
@@ -218,14 +191,15 @@ MainWindow::MainWindow(QWidget *parent, const char *name):QWidget(parent,name)
 
   mainlayout->activate();
 
-  config->setGroup("Geometry");
-  this->setGeometry(config->readRectEntry("MainWindowGeo",&DefaultRect));
-
 
   if (kapp->isRestored())
    {
     KConfig *kc;
+#if QT_VERSION >= 200
+    kc=kapp->sessionConfig();
+#else
     kc=kapp->getSessionConfig();
+#endif
     if (kc!=0) loadProjectFromConfig(kc);
    }
  
@@ -233,53 +207,6 @@ MainWindow::MainWindow(QWidget *parent, const char *name):QWidget(parent,name)
   updateTrackSum();
  }
 
-void MainWindow::resizeEvent(QResizeEvent *)
- {
-  QSize minsize;
-
-  int WindowH,BaseY;
-
-  int MenuPos;
-
-  WindowH=height();
-
-  MenuPos=MWMenu->menuBarPos();
-
-  switch (MenuPos)
-   {
-    case KMenuBar::Top:
-      BaseY=MWMenu->height();
-      WindowH-=BaseY;
-      MWMenu->setGeometry(0,0,this->width(),MWMenu->height());
-      break;
-    case KMenuBar::Bottom:
-      BaseY=0;
-      WindowH-=MWMenu->height();
-      MWMenu->setGeometry(0,WindowH,this->width(),MWMenu->height());
-      break;
-    case KMenuBar::Floating:
-      BaseY=0;
-      break;
-    default:
-      BaseY=0;
-      break;
-   }
-  
-  if (FirstInvoke)
-   {
-    FirstInvoke=0;
-   }
-   else
-   {
-    readColWidth();
-   }
-  MainWidget->setGeometry(0,BaseY,this->width(),WindowH);
-  minsize=MainWidget->minimumSize();
-  if (MenuPos!=KMenuBar::Floating) minsize.rheight()+=MWMenu->height();
-  this->setMinimumSize(minsize);
-  writeColWidth();
- }
-
 
 void MainWindow::checkWidgetEnable()
  {
@@ -465,11 +392,6 @@ void MainWindow::notifyCloseISOWin(void)
   ISOWindow=0;
  }
 
-void MainWindow::menuMoved()
- {
-  resizeEvent(0);
- }
-
 void MainWindow::updateTrackSum(void)
  {
   long int dura;
@@ -486,7 +408,7 @@ void MainWindow::updateTrackSum(void)
    {
     char format1[80],format2[20];
     CDTrack::getDurationHMSB(format2,dura);
-    sprintf(format1,locale->translate("Tracks in project : %d ( duration %s )"),
+    sprintf(format1,locale->translate("Tracks in project: %d (duration %s)"),
             tr,format2);
     SumLabel->setText(format1);
    }
@@ -556,7 +478,11 @@ void MainWindow::configISO()
 void MainWindow::saveSession()
  {
   KConfig *kc;
+#if QT_VERSION >= 200
+  kc=kapp->sessionConfig();
+#else
   kc=kapp->getSessionConfig();
+#endif
   if (kc!=0) saveProjectToConfig(kc);
  }
 
@@ -675,7 +601,7 @@ void MainWindow::readColWidth()
 void MainWindow::writeColWidth()
  {
   int sum=0,i;
-  sum=MainWidget->width();
+  sum=this->width();
   if (sum==0) return;
   for (i=0;i<TRACK_COLUMNS;++i)
    {
@@ -684,3 +610,46 @@ void MainWindow::writeColWidth()
  }
 
 
+void MainWindow::blankAll(void)
+ {
+  CDRWBlank cbl;
+  cbl.blankMedia(CDRWBlank::Blank_All);
+ }
+
+void MainWindow::blankFast(void)
+ {
+  CDRWBlank cbl;
+  cbl.blankMedia(CDRWBlank::Blank_Fast);
+ }
+
+void MainWindow::blankTrack(void)
+ {
+  CDRWBlank cbl;
+  cbl.blankMedia(CDRWBlank::Blank_Track);
+ }
+
+void MainWindow::blankUnreserve(void)
+ {
+  CDRWBlank cbl;
+  cbl.blankMedia(CDRWBlank::Blank_Unreserve);
+ }
+
+void MainWindow::blankTail(void)
+ {
+  CDRWBlank cbl;
+  cbl.blankMedia(CDRWBlank::Blank_Tail);
+ }
+
+void MainWindow::blankUnclose(void)
+ {
+  CDRWBlank cbl;
+  cbl.blankMedia(CDRWBlank::Blank_Unclose);
+ }
+
+void MainWindow::blankSession(void)
+ {
+  CDRWBlank cbl;
+  cbl.blankMedia(CDRWBlank::Blank_Session);
+ }
+
+
