@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General
 // Public License.  See the file COPYING in the main directory of the
@@ -20,13 +20,11 @@ class MainWindow : public QWidget
          ~MainWindow(void);
 
   protected:
-         void resizeEvent(QResizeEvent *qresize);
          void saveProjectToConfig(class KConfig *kc);
          void loadProjectFromConfig(class KConfig *kc);
          void checkWidgetEnable(void);
 
   protected slots:
-         void menuMoved(void); 
          void saveSession(void);
          void addTrack(void);
          void editTrack(void);
@@ -59,16 +57,22 @@ class MainWindow : public QWidget
 
          void normalizeMax(void);
          void normalizeAllSame(void);
+
+         void blankAll(void);
+         void blankFast(void);
+         void blankTrack(void);
+         void blankUnreserve(void);
+         void blankTail(void);
+         void blankUnclose(void);
+         void blankSession(void);
+
   private:
          void readColWidth(void);
          void writeColWidth(void);
 
          int FirstInvoke;
          int Colwidth[TRACK_COLUMNS];
-         
-         class KMenuBar      *MWMenu;
-         
-         class QWidget       *MainWidget;
+
          class QListView     *MWTracklist;
          class QPushButton   *MWAddTrack;
          class QPushButton   *MWEditTrack;
@@ -90,7 +94,5 @@ class MainWindow : public QWidget
          class ISOOptions    *ISOWindow;
          
          char                 ProjectPath[1024];
-
-
  };
 
