@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General
 // Public License.  See the file COPYING in the main directory of the
@@ -65,7 +65,7 @@ void MainWindow::openProject(void)
   QString openname;
   newProject();
 #if QT_VERSION >= 200
-  openname=KFileDialog::getOpenFileName(QString::null,"*.cdp",this,locale->translate("Open project"));
+  openname=KFileDialog::getOpenURL(QString::null,"*.cdp",this,locale->translate("Open project")).path();
   KURL::decode(openname);
 #else
   openname=KFileDialog::getOpenFileName(0,"*.cdp",this,locale->translate("Open project"));
@@ -90,7 +90,7 @@ void MainWindow::saveProject(void)
   if (ProjectPath[0]==0)
    {
 #if QT_VERSION >= 200
-    savename=KFileDialog::getSaveFileName(QString::null,"*.cdp",this,locale->translate("Save project"));
+    savename=KFileDialog::getSaveURL(QString::null,"*.cdp",this,locale->translate("Save project")).path();
     KURL::decode(savename);
 #else
     savename=KFileDialog::getSaveFileName(0,"*.cdp",this,locale->translate("Save project"));
