@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General
 // Public License.  See the file COPYING in the main directory of the
@@ -9,7 +9,9 @@
 #include "MainWindow.h"
 #include "CDTrack.h"
 #include "AudioFile.h"
-#include "DriveAccess.h"
+#include "AudioScanImage.h"
+#include "TOCReader.h"
+#include "AppChooser.h"
 
 #include <qwidget.h>
 #include <qpushbutton.h>
@@ -35,10 +37,11 @@
 void MainWindow::setupCopy(void)
  {
   int i;
-  DriveAccess da;
+  TOCReader *toc;
   newProject();
 
-  if (!da.readTOC())
+  toc=AppChooser::readTOC();
+  if (toc==0)
    {
     return;
    }
@@ -46,7 +49,7 @@ void MainWindow::setupCopy(void)
   while (1)
 
    {
-    if (da.getTOCDuration(i+1)==-1) break;
+    if (toc->getTOCDuration(i+1)==-1) break;
     ProjectTracks[i]=new CDTrack();
     if (ProjectTracks[i]==0) break;
      {
@@ -54,9 +57,9 @@ void MainWindow::setupCopy(void)
       sprintf(trd,"Track %d",i+1);
       ProjectTracks[i]->setDescription(trd);
      }
-    ProjectTracks[i]->setTrackType(ProjectTracks[i]->getTOCType(da.getTOCType(i+1),da.getTOCMode(i+1)));
-    ProjectTracks[i]->setSourceTrack(i+1,da.getTOCSum(),da.getTOCDuration(i+1),
-                                     da.getTOCLBA(i+1));
+    ProjectTracks[i]->setTrackType(toc->getTOCType(i+1));
+    ProjectTracks[i]->setSourceTrack(i+1,toc->getTOCSum(),toc->getTOCDuration(i+1),
+                                     toc->getTOCLBA(i+1));
 
     TrackItems[i]=new QListViewItem(MWTracklist);
     if (TrackItems[i]==0)
@@ -73,7 +76,9 @@ void MainWindow::setupCopy(void)
    }
   CurrentTrack=-1;
   checkWidgetEnable();
- }
+  updateTrackSum();
+  delete toc;
+}
 
 void MainWindow::normalizeMax(void)
  {
@@ -89,7 +94,10 @@ void MainWindow::normalizeMax(void)
      }
     audi=ProjectTracks[i]->getAudioFile();
     if (audi==0) continue;
-    audi->setMaxBoost();
+     {
+      AudioScanImage img(audi);
+      img.setMaxBoost();
+     }
     ProjectTracks[i]->clearImage();
     cboost=audi->getBoost();
    }
@@ -111,7 +119,10 @@ void MainWindow::normalizeAllSame(void)
     audi=ProjectTracks[i]->getAudioFile();
     if (audi==0) continue;
     ProjectTracks[i]->clearImage();
-    audi->setMaxBoost();
+     {
+      AudioScanImage img(audi);
+      img.setMaxBoost();
+     }
     cboost=audi->getBoost();
     if (cboost<mmboost) mmboost=cboost;
    }
