@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -14,7 +14,7 @@ class TrackDialog : public QDialog
  {
   Q_OBJECT;
   public:
-    TrackDialog( QWidget *parent=0, const char *name=0,class DriveAccess *dracc=0);
+    TrackDialog( QWidget *parent=0, const char *name=0,class TOCReader *toc=0);
  
   protected slots:
     void changeCurrent(QListViewItem *change);
