@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -9,12 +9,13 @@
 #include "TrackWindow.h"
 #include "CDTrack.h"
 #include "AudioFile.h"
-#include "DriveAccess.h"
+#include "TOCReader.h"
 #include "TrackDialog.h"
 #include "AudioOptions.h"
 #include "IsoOptions.h"
 #include "IsoWindow.h"
 #include "IsoImage.h"
+#include "AppChooser.h"
 
 #include <qlabel.h>
 #include <qcheckbox.h>
@@ -30,7 +31,11 @@
 #include <kconfig.h>
 #include <kapp.h>
 #include <klocale.h>
+#if QT_VERSION >= 200
+#include <klineedit.h>
+#else
 #include <klined.h>
+#endif
 #include <kfiledialog.h>
 #include <kurl.h>
 
@@ -52,7 +57,11 @@ TrackWindow::TrackWindow( QWidget *parent, const char *name,CDTrack *track):QWid
  
   ignsigs=0;
   ThisTrack=track;
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   AudioOptWindow=0;
   ISOTreeWindow=0;
   ISOOptWindow=0;
@@ -127,7 +136,7 @@ TrackWindow::TrackWindow( QWidget *parent, const char *name,CDTrack *track):QWid
   leftlayout->addWidget(ButtonSelectSource);
 
   // Build options button
-  ButtonOptions=new QPushButton(locale->translate("Options ..."),this,"track options");
+  ButtonOptions=new QPushButton(locale->translate("Options..."),this,"track options");
   ButtonOptions->setMinimumSize(ButtonOptions->sizeHint());
   leftlayout->addWidget(ButtonOptions);
 
@@ -182,7 +191,11 @@ TrackWindow::~TrackWindow(void)
  {
   KConfig *config;
   QRect SaveRect(this->pos(),this->size());
+#if QT_VERSION >= 200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   config->setGroup("Geometry");
   config->writeEntry("TrackWindowGeo",SaveRect);
   if (AudioOptWindow!=0) delete(AudioOptWindow);
@@ -235,7 +248,11 @@ void TrackWindow::changeSourceType(int sourcetype)
  {
   KConfig *config;
 
+#if QT_VERSION >=200
+  config=kapp->config();
+#else
   config=kapp->getConfig();
+#endif
   if (ignsigs) return;
   if (AudioOptWindow!=0) AudioOptWindow->hide();
   if (ISOTreeWindow!=0) ISOTreeWindow->hide();
@@ -248,9 +265,9 @@ void TrackWindow::changeSourceType(int sourcetype)
       break;
     case 1:
       {
-       DriveAccess da;      
+       TOCReader *toc;
        int seltrack;
-       if (!da.readTOC())
+       if ((toc=AppChooser::readTOC())==0)
         {
 #if QT_VERSION >= 200
          QMessageBox::critical(this,QString::null,locale->translate("No disc in drive!"));
@@ -262,16 +279,16 @@ void TrackWindow::changeSourceType(int sourcetype)
       
         {
          TrackDialog *dd;
-         dd=new TrackDialog(this,0,&da);
+         dd=new TrackDialog(this,0,toc);
          seltrack=dd->exec();
          delete(dd);
          if (seltrack!=0)
           {
-           ThisTrack->setTrackType(ThisTrack->getTOCType(da.getTOCType(seltrack),da.getTOCMode(seltrack)));
-           ThisTrack->setSourceTrack(seltrack,da.getTOCSum(),da.getTOCDuration(seltrack),
-                                     da.getTOCLBA(seltrack));
+           ThisTrack->setTrackType(toc->getTOCType(seltrack));
+           ThisTrack->setSourceTrack(seltrack,toc->getTOCSum(),toc->getTOCDuration(seltrack),
+                                     toc->getTOCLBA(seltrack));
           }
-
+          delete toc;
         }
        break;
       }
@@ -279,7 +296,11 @@ void TrackWindow::changeSourceType(int sourcetype)
       {
        QString qs;
        config->setGroup("Path");
+#if QT_VERSION >=200
+       qs=KFileDialog::getOpenURL(config->readEntry("PathDatafile","")).path();
+#else
        qs=KFileDialog::getOpenFileName(config->readEntry("PathDatafile",""));
+#endif
        if (qs.isEmpty()) break;
 #if QT_VERSION >=200
        KURL::decode(qs);
@@ -434,7 +455,7 @@ void TrackWindow::updateWindow(void)
       int realsiz;
 
       afile->getFormat(format);
-      sprintf(tempstring,locale->translate("Format : %s\n\n"),format);
+      sprintf(tempstring,locale->translate("Format: %s\n\n"),format);
       strcat(properties,tempstring);
       endi=afile->getEndian();
       if (endi==AudioFile::Endian_Little)
@@ -451,18 +472,18 @@ void TrackWindow::updateWindow(void)
       if (sasi==AudioFile::Samples_32Bit) realsiz=32;
       sprintf(tempstring,locale->translate("%d Channels - %d Bits\n"),afile->getChannels(),realsiz);
       strcat(properties,tempstring);
-      sprintf(tempstring,locale->translate("Sample rate : %ld\n\n"),afile->getSampleRate());
+      sprintf(tempstring,locale->translate("Sample rate: %ld\n\n"),afile->getSampleRate());
       CDTrack::getDurationHMSB(format,afile->getAbsoluteDuration());
       strcat(properties,tempstring);
-      sprintf(tempstring,locale->translate("Absolute length : %s\n"),format);
+      sprintf(tempstring,locale->translate("Absolute length: %s\n"),format);
       strcat(properties,tempstring);
       CDTrack::getDurationHMSB(format,afile->getSelectedDuration());
-      sprintf(tempstring,locale->translate("Selected length : %s\n\n"),format);
+      sprintf(tempstring,locale->translate("Selected length: %s\n\n"),format);
       strcat(properties,tempstring);
-      sprintf(tempstring,locale->translate("Boost factor    : %f\n\n"),
+      sprintf(tempstring,locale->translate("Boost factor   : %f\n\n"),
            afile->getBoost());
       strcat(properties,tempstring);
-      sprintf(tempstring,locale->translate("Balance         : %f\n\n"),
+      sprintf(tempstring,locale->translate("Balance        : %f\n\n"),
            afile->getBalance());
       strcat(properties,tempstring);
 
