@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -53,7 +53,7 @@ WriteDialog::WriteDialog( QWidget *parent, const char *name,int ntracks,CDTrack
   // set defaults - do prefs later
 
   Burnspeed=4;
-  XFixating=DriveAccess::Fix_CD;
+  XFixating=CDWriter::Fix_CD;
   Simmode=0;
   XEject=0;
 
@@ -133,13 +133,13 @@ WriteDialog::WriteDialog( QWidget *parent, const char *name,int ntracks,CDTrack
 
   switch (XFixating)
    {
-    case DriveAccess::Fix_None:
+    case CDWriter::Fix_None:
      fixating->setButton(0);
      break;
-    case DriveAccess::Fix_Session:
+    case CDWriter::Fix_Session:
      fixating->setButton(1);
      break;
-    case DriveAccess::Fix_CD:
+    case CDWriter::Fix_CD:
      fixating->setButton(2);
      break;
    }
@@ -161,8 +161,8 @@ WriteDialog::WriteDialog( QWidget *parent, const char *name,int ntracks,CDTrack
 
 void WriteDialog::writeCD(void)
  {
-  DriveAccess *da;
-  da=new DriveAccess();
+  CDWriter *da;
+  da=new CDWriter();
   int ret;
   long int blcks;
   if (da==0) return;
@@ -171,14 +171,14 @@ void WriteDialog::writeCD(void)
 #if QT_VERSION >= 200
     QString buffer;
 
-    buffer=locale->translate("WARNING : Data does not fit on disk:\n%ld blocks missing").arg(-blcks);
+    buffer=locale->translate("WARNING: Data does not fit on disk:\n%ld blocks missing").arg(-blcks);
     ret=QMessageBox::information(0,QString::null,buffer,
               locale->translate("Continue"),
               locale->translate("Cancel"));
 #else
     char buffer[256];
 
-    sprintf(buffer,locale->translate("WARNING : Data does not fit on disk:\n%ld blocks missing"),-blcks);
+    sprintf(buffer,locale->translate("WARNING: Data does not fit on disk:\n%ld blocks missing"),-blcks);
     ret=QMessageBox::information(0,0,buffer,
               locale->translate("Continue"),
               locale->translate("Cancel"));
@@ -209,13 +209,13 @@ void WriteDialog::changeFixating(int id)
   switch (id)
    {
     case 0:
-      XFixating=DriveAccess::Fix_None;
+      XFixating=CDWriter::Fix_None;
       break;
     case 1:
-      XFixating=DriveAccess::Fix_Session;
+      XFixating=CDWriter::Fix_Session;
       break;
     case 2:
-      XFixating=DriveAccess::Fix_CD;
+      XFixating=CDWriter::Fix_CD;
       break;
    }
  }
