@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
@@ -10,7 +10,7 @@
 #include <qdialog.h>
 #include <qlistview.h>
 
-#include "DriveAccess.h"
+#include "CDWriter.h"
 
 class CDTrack;
 
@@ -37,7 +37,7 @@ class WriteDialog : public QDialog
     int      numtracks;
 
     int                   Burnspeed;
-    DriveAccess::Fixating XFixating;
+    CDWriter::Fixating XFixating;
     int                   Simmode;
     int                   XEject;
 
