@@ -1,17 +1,15 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General      
 // Public License.  See the file COPYING in the main directory of the       
 // KreateCD distribution for more details.                                     
 
 
-#include "MainWindow.h"
+#include "TopWidget.h"
 #include "CDTrack.h"
 #include "ConfPath.h"
-#include "DriveAccess.h"
-
 
 #include <kapp.h>
 #include <klocale.h>
@@ -22,6 +20,7 @@
 
 
 KLocale *locale;
+TopWidget *MainWin;
 
 int callUID,callGID;
 
@@ -80,12 +79,15 @@ int main(int argc,char **argv)
                                            "Please visit the path configuration!"));
    }
 #endif
-  MainWindow MainWin;
     
+#if QT_VERSION < 200
   KreateCDApp.enableSessionManagement(FALSE);
-  KreateCDApp.setMainWidget(&MainWin);
-  KreateCDApp.setTopWidget(&MainWin);
+#endif
 
-  MainWin.show(); 
+  MainWin=new TopWidget();
+  KreateCDApp.setMainWidget(MainWin);
+  KreateCDApp.setTopWidget(MainWin);
+
+  MainWin->show(); 
   return(KreateCDApp.exec());
  }
