@@ -1,6 +1,6 @@
 // KreateCD - CD recording software for the K desktop environment
 //
-// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
+// 1999-2000 by Alexander Feigl <Alexander.Feigl@gmx.de>
 //
 // This file is subject to the terms and conditions of the GNU General
 // Public License.  See the file COPYING in the main directory of the
@@ -9,3 +9,6 @@
 int getRootRights();
 int dropRootRights();
 
+#define ROOT_CALLED  ( (callUID==0) && (callGID==0) )
+
+extern int callUID,callGID;
